SyncEaseLogic class

The SyncEaseLogic class manages the registration and retrieval of logic instances for state management.

Constructors

SyncEaseLogic()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Adds a listener function to be called when the state changes.
clear() → void
Clears the logic instance and associated data.
errorLog(String message) → void
Logs an error message.
infoLog(String message) → void
Logs an informational message.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onClear() → void
Clears all data associated with the logic instance.
onGet() → void
Notification method called when retrieving the logic instance.
onInit() → void
Initialization method called when registering the logic instance.
onReady() → void
Notification method called when retrieving the logic instance.
onRegistered() → void
Initialization method called when registering the logic instance.
put() → void
Updates the state and notifies listeners.
removeListener(VoidCallback listener) → void
Removes a listener function to stop receiving state change notifications.
successLog(String message) → void
Logs a success message.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

get<T extends SyncEaseLogic>() → T
Retrieves a registered instance of SyncEaseLogic of the specified type T.
reg(SyncEaseLogic syncEaseLogic, {bool replace = true}) → dynamic
Registers a new instance of SyncEaseLogic.
remove<T extends SyncEaseLogic>() → void
Remove a registered instance of SyncEaseLogic of the specified type T.
removeIfRegistered<T extends SyncEaseLogic>() → void